diff --git a/CHANGELOG.md b/CHANGELOG.md
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,4 +1,9 @@
 
+Version 0.7
+-----
+
+* Fixed the use of the LP abbreviation.
+
 Version 0.6
 -----
 
diff --git a/Simulation/Aivika/Distributed/Optimistic/Internal/Event.hs b/Simulation/Aivika/Distributed/Optimistic/Internal/Event.hs
--- a/Simulation/Aivika/Distributed/Optimistic/Internal/Event.hs
+++ b/Simulation/Aivika/Distributed/Optimistic/Internal/Event.hs
@@ -322,7 +322,7 @@
        invokeTimeWarp p' throttleMessageChannel
 
 -- | Process the channel message.
-processChannelMessage :: LocalProcessMessage -> TimeWarp DIO ()
+processChannelMessage :: LogicalProcessMessage -> TimeWarp DIO ()
 processChannelMessage x@(QueueMessage m) =
   TimeWarp $ \p ->
   do let q = runEventQueue $ pointRun p
@@ -422,7 +422,7 @@
      ---
      invokeEvent p $
        reconnectProcess pid
-processChannelMessage x@(KeepAliveLocalProcessMessage m) =
+processChannelMessage x@(KeepAliveLogicalProcessMessage m) =
   TimeWarp $ \p ->
   do let q = runEventQueue $ pointRun p
      ---
@@ -494,7 +494,7 @@
   showString " }"
 
 -- | Log the message at the specified time.
-logMessage :: LocalProcessMessage -> Event DIO ()
+logMessage :: LogicalProcessMessage -> Event DIO ()
 logMessage (QueueMessage m) =
   Event $ \p ->
   logDIO INFO $
@@ -769,7 +769,7 @@
 
 -- | Suspend the 'Event' computation until the specified computation is determined.
 --
--- The tested computation should depend on messages that come from other local processes.
+-- The tested computation should depend on messages that come from other logical processes.
 -- Moreover, the event must be initiated through the event queue.
 expectEvent :: Event DIO (Maybe a) -> (a -> Event DIO ()) -> Event DIO ()
 expectEvent m cont =
diff --git a/Simulation/Aivika/Distributed/Optimistic/Internal/Expect.hs b/Simulation/Aivika/Distributed/Optimistic/Internal/Expect.hs
--- a/Simulation/Aivika/Distributed/Optimistic/Internal/Expect.hs
+++ b/Simulation/Aivika/Distributed/Optimistic/Internal/Expect.hs
@@ -27,11 +27,11 @@
 
 -- | Suspend the 'Process' until the specified computation is determined.
 --  
--- The tested computation should depend on messages that come from other local processes.
+-- The tested computation should depend on messages that come from other logical processes.
 -- Moreover, the process must be initiated through the event queue.
 --
 -- In the current implementation there is a limitation that this function can be used only
--- once for the entire local process simulation; otherwise, a race condition may arise.
+-- once for the entire logical process simulation; otherwise, a race condition may arise.
 expectProcess :: Event DIO (Maybe a) -> Process DIO a
 expectProcess m =
   Process $ \pid ->
diff --git a/aivika-distributed.cabal b/aivika-distributed.cabal
--- a/aivika-distributed.cabal
+++ b/aivika-distributed.cabal
@@ -1,5 +1,5 @@
 name:            aivika-distributed
-version:         0.6
+version:         0.7
 synopsis:        Parallel distributed discrete event simulation module for the Aivika library
 description:
     This package extends the aivika-transformers [1] package and allows running parallel distributed simulations.
@@ -8,8 +8,8 @@
     .
     Moreover, this package uses the author's modification that allows recovering the distributed
     simulation after temporary connection errors whenever possible. For that, you have to enable explicitly 
-    the recovering mode and enable monitoring all local processes including the specialized Time Server process 
-    as it is shown in one of the test examples included in the distributive.
+    the recovering mode and enable monitoring all logical processes including the specialized Time Server process 
+    as it is shown in one of the test examples included in the distribution.
     .
     With the recovering mode enabled, you can try to build a distributed simulation using ordinary computers connected
     via the ordinary net. For example, such a distributed model could even consist of computers located in different 
@@ -27,10 +27,10 @@
     .
     Regarding the speed of simulation, the rough estimations are as follows. The distributed simulation module is slower up to
     6-9 times in comparison with the sequential aivika [2] simulation library using the equivalent sequential models. 
-    Note that you can run up to 7 parallel local processes on a single 8-core processor computer and run the Time Server 
-    process too. On a 36-core processor, you can launch up to 35 local processes simultaneously.
+    Note that you can run up to 7 parallel logical processes on a single 8-core processor computer and run the Time Server 
+    process too. On a 36-core processor, you can launch up to 35 logical processes simultaneously.
     . 
-    So, this estimation seems to be quite good. At the same time, the message passing between the local processes can 
+    So, this estimation seems to be quite good. At the same time, the message passing between the logical processes can 
     dramatically decrease the speed of distributed simulation, especially if they cause rollbacks. Thus, much depends on 
     the distributed model itself.
     .

diff --git a/Simulation/Aivika/Distributed/Optimistic/Internal/DIO.hs b/Simulation/Aivika/Distributed/Optimistic/Internal/DIO.hs
--- a/Simulation/Aivika/Distributed/Optimistic/Internal/DIO.hs
+++ b/Simulation/Aivika/Distributed/Optimistic/Internal/DIO.hs
@@ -100,7 +100,7 @@
 
 -- | The context of the 'DIO' computation.
 data DIOContext =
-  DIOContext { dioChannel :: Channel LocalProcessMessage,
+  DIOContext { dioChannel :: Channel LogicalProcessMessage,
                -- ^ The channel of messages.
                dioInboxId :: DP.ProcessId,
                -- ^ The inbox process identifier.
@@ -186,7 +186,7 @@
 dioParams = DIO $ return . dioParams0
 
 -- | Return the chanel of messages.
-messageChannel :: DIO (Channel LocalProcessMessage)
+messageChannel :: DIO (Channel LogicalProcessMessage)
 messageChannel = DIO $ return . dioChannel
 
 -- | Return the process identifier of the inbox that receives messages.
@@ -229,8 +229,8 @@
      receiver <- invokeDIO ctx timeServerId
      let inbox = sender
      if dioProcessMonitoringEnabled ps
-       then DP.send inbox (SendRegisterLocalProcessMessage receiver sender)
-       else DP.send receiver (RegisterLocalProcessMessage sender)
+       then DP.send inbox (SendRegisterLogicalProcessMessage receiver sender)
+       else DP.send receiver (RegisterLogicalProcessMessage sender)
      liftIO $
        timeout (dioTimeServerAcknowledgmentTimeout ps) $
        atomically $
@@ -250,8 +250,8 @@
      receiver <- invokeDIO ctx timeServerId
      let inbox = sender
      if dioProcessMonitoringEnabled ps
-       then DP.send inbox (SendUnregisterLocalProcessMessage receiver sender)
-       else DP.send receiver (UnregisterLocalProcessMessage sender)
+       then DP.send inbox (SendUnregisterLogicalProcessMessage receiver sender)
+       else DP.send receiver (UnregisterLogicalProcessMessage sender)
      liftIO $
        timeout (dioTimeServerAcknowledgmentTimeout ps) $
        atomically $
@@ -260,15 +260,15 @@
      DP.send inbox TerminateInboxProcessMessage
      return ()
 
--- | The internal local process message.
-data InternalLocalProcessMessage = InternalLocalProcessMessage LocalProcessMessage
-                                   -- ^ the local process message
-                                 | InternalProcessMonitorNotification DP.ProcessMonitorNotification
-                                   -- ^ the process monitor notification
-                                 | InternalInboxProcessMessage InboxProcessMessage
-                                   -- ^ the inbox process message
-                                 | InternalKeepAliveMessage KeepAliveMessage
-                                   -- ^ the keep alive message
+-- | The internal logical process message.
+data InternalLogicalProcessMessage = InternalLogicalProcessMessage LogicalProcessMessage
+                                     -- ^ the logical process message
+                                   | InternalProcessMonitorNotification DP.ProcessMonitorNotification
+                                     -- ^ the process monitor notification
+                                   | InternalInboxProcessMessage InboxProcessMessage
+                                     -- ^ the inbox process message
+                                   | InternalKeepAliveMessage KeepAliveMessage
+                                     -- ^ the keep alive message
 
 -- | Handle the specified exception.
 handleException :: DIOParams -> SomeException -> DP.Process ()
@@ -293,18 +293,18 @@
      timeServerTerminating <- liftIO $ newTVarIO False
      let loop =
            forever $
-           do let f1 :: LocalProcessMessage -> DP.Process InternalLocalProcessMessage
-                  f1 x = return (InternalLocalProcessMessage x)
-                  f2 :: DP.ProcessMonitorNotification -> DP.Process InternalLocalProcessMessage
+           do let f1 :: LogicalProcessMessage -> DP.Process InternalLogicalProcessMessage
+                  f1 x = return (InternalLogicalProcessMessage x)
+                  f2 :: DP.ProcessMonitorNotification -> DP.Process InternalLogicalProcessMessage
                   f2 x = return (InternalProcessMonitorNotification x)
-                  f3 :: InboxProcessMessage -> DP.Process InternalLocalProcessMessage
+                  f3 :: InboxProcessMessage -> DP.Process InternalLogicalProcessMessage
                   f3 x = return (InternalInboxProcessMessage x)
-                  f4 :: KeepAliveMessage -> DP.Process InternalLocalProcessMessage
+                  f4 :: KeepAliveMessage -> DP.Process InternalLogicalProcessMessage
                   f4 x = return (InternalKeepAliveMessage x)
               x <- fmap Just $ DP.receiveWait [DP.match f1, DP.match f2, DP.match f3, DP.match f4]
               case x of
                 Nothing -> return ()
-                Just (InternalLocalProcessMessage m) ->
+                Just (InternalLogicalProcessMessage m) ->
                   liftIO $
                   writeChannel ch m
                 Just (InternalProcessMonitorNotification m@(DP.ProcessMonitorNotification _ _ _)) ->
@@ -325,10 +325,10 @@
                       DP.send receiver (LocalTimeMessage sender t)
                     SendRequestGlobalTimeMessage receiver sender ->
                       DP.send receiver (RequestGlobalTimeMessage sender)
-                    SendRegisterLocalProcessMessage receiver sender ->
-                      DP.send receiver (RegisterLocalProcessMessage sender)
-                    SendUnregisterLocalProcessMessage receiver sender ->
-                      DP.send receiver (UnregisterLocalProcessMessage sender)
+                    SendRegisterLogicalProcessMessage receiver sender ->
+                      DP.send receiver (RegisterLogicalProcessMessage sender)
+                    SendUnregisterLogicalProcessMessage receiver sender ->
+                      DP.send receiver (UnregisterLogicalProcessMessage sender)
                     SendTerminateTimeServerMessage receiver sender ->
                       DP.send receiver (TerminateTimeServerMessage sender)
                     MonitorProcessMessage pid ->
@@ -343,16 +343,16 @@
                       handleReMonitorProcessMessage pids ps ch
                     TrySendKeepAliveMessage ->
                       trySendKeepAlive keepAliveManager
-                    RegisterLocalProcessAcknowledgmentMessage pid ->
+                    RegisterLogicalProcessAcknowledgmentMessage pid ->
                       do ---
-                         logProcess ps INFO "Registered the local process in the time server"
+                         logProcess ps INFO "Registered the logical process in the time server"
                          ---
                          liftIO $
                            atomically $
                            writeTVar registeredInTimeServer True
-                    UnregisterLocalProcessAcknowledgmentMessage pid ->
+                    UnregisterLogicalProcessAcknowledgmentMessage pid ->
                       do ---
-                         logProcess ps INFO "Unregistered the local process from the time server"
+                         logProcess ps INFO "Unregistered the logical process from the time server"
                          ---
                          liftIO $
                            atomically $
@@ -376,7 +376,7 @@
                      logProcess ps DEBUG $ "Received " ++ show m
                      ---
                      liftIO $
-                       writeChannel ch (KeepAliveLocalProcessMessage m)
+                       writeChannel ch (KeepAliveLogicalProcessMessage m)
      inboxId <-
        DP.spawnLocal $
        C.catch loop (handleException ps)
@@ -400,7 +400,7 @@
      return (inboxId, simulation)
 
 -- | Handle the process monitor notification.
-handleProcessMonitorNotification :: DP.ProcessMonitorNotification -> DIOParams -> Channel LocalProcessMessage -> DP.Process ()
+handleProcessMonitorNotification :: DP.ProcessMonitorNotification -> DIOParams -> Channel LogicalProcessMessage -> DP.Process ()
 handleProcessMonitorNotification m@(DP.ProcessMonitorNotification _ pid0 reason) ps ch =
   do let recv m@(DP.ProcessMonitorNotification _ _ _) = 
            do ---
@@ -442,7 +442,7 @@
           return ()
 
 -- | Re-monitor the specified remote processes.
-handleReMonitorProcessMessage :: [DP.ProcessId] -> DIOParams -> Channel LocalProcessMessage -> DP.Process ()
+handleReMonitorProcessMessage :: [DP.ProcessId] -> DIOParams -> Channel LogicalProcessMessage -> DP.Process ()
 handleReMonitorProcessMessage pids ps ch =
   forM_ pids $ \pid ->
   do ---
diff --git a/Simulation/Aivika/Distributed/Optimistic/Internal/Message.hs b/Simulation/Aivika/Distributed/Optimistic/Internal/Message.hs
--- a/Simulation/Aivika/Distributed/Optimistic/Internal/Message.hs
+++ b/Simulation/Aivika/Distributed/Optimistic/Internal/Message.hs
@@ -17,7 +17,7 @@
         antiMessages,
         AcknowledgmentMessage(..),
         acknowledgmentMessage,
-        LocalProcessMessage(..),
+        LogicalProcessMessage(..),
         TimeServerMessage(..),
         InboxProcessMessage(..),
         KeepAliveMessage(..)) where
@@ -106,51 +106,51 @@
                           acknowledgmentMarked = marked
                         }
 
--- | The message sent to the local process.
-data LocalProcessMessage = QueueMessage Message
-                           -- ^ the message has come from the remote process
-                         | QueueMessageBulk [Message]
-                           -- ^ a bulk of messages that have come from the remote process
-                         | AcknowledgmentQueueMessage AcknowledgmentMessage
-                           -- ^ the acknowledgment message has come from the remote process
-                         | AcknowledgmentQueueMessageBulk [AcknowledgmentMessage]
-                           -- ^ a bulk of acknowledgment messages that have come from the remote process
-                         | ComputeLocalTimeMessage
-                           -- ^ the time server requests for a local minimum time
-                         | GlobalTimeMessage Double
-                           -- ^ the time server sent a global time
-                         | ProcessMonitorNotificationMessage DP.ProcessMonitorNotification
-                           -- ^ the process monitor notification
-                         | ReconnectProcessMessage DP.ProcessId
-                           -- ^ finish reconnecting to the specified process
-                         | KeepAliveLocalProcessMessage KeepAliveMessage
-                           -- ^ the keep alive message for the local process
-                         deriving (Show, Typeable, Generic)
+-- | The message sent to the logical process.
+data LogicalProcessMessage = QueueMessage Message
+                             -- ^ the message has come from the remote process
+                           | QueueMessageBulk [Message]
+                             -- ^ a bulk of messages that have come from the remote process
+                           | AcknowledgmentQueueMessage AcknowledgmentMessage
+                             -- ^ the acknowledgment message has come from the remote process
+                           | AcknowledgmentQueueMessageBulk [AcknowledgmentMessage]
+                             -- ^ a bulk of acknowledgment messages that have come from the remote process
+                           | ComputeLocalTimeMessage
+                             -- ^ the time server requests for a local minimum time
+                           | GlobalTimeMessage Double
+                             -- ^ the time server sent a global time
+                           | ProcessMonitorNotificationMessage DP.ProcessMonitorNotification
+                             -- ^ the process monitor notification
+                           | ReconnectProcessMessage DP.ProcessId
+                             -- ^ finish reconnecting to the specified process
+                           | KeepAliveLogicalProcessMessage KeepAliveMessage
+                             -- ^ the keep alive message for the logical process
+                           deriving (Show, Typeable, Generic)
 
-instance Binary LocalProcessMessage
+instance Binary LogicalProcessMessage
 
 -- | The time server message.
-data TimeServerMessage = RegisterLocalProcessMessage DP.ProcessId
-                         -- ^ register the local process in the time server
-                       | UnregisterLocalProcessMessage DP.ProcessId
-                         -- ^ unregister the local process from the time server
+data TimeServerMessage = RegisterLogicalProcessMessage DP.ProcessId
+                         -- ^ register the logical process in the time server
+                       | UnregisterLogicalProcessMessage DP.ProcessId
+                         -- ^ unregister the logical process from the time server
                        | TerminateTimeServerMessage DP.ProcessId
                          -- ^ the local process asked to terminate the time server
                        | RequestGlobalTimeMessage DP.ProcessId
                          -- ^ the local process requested for the global minimum time
                        | LocalTimeMessage DP.ProcessId Double
                          -- ^ the local process sent its local minimum time
                        | ReMonitorTimeServerMessage [DP.ProcessId]
                          -- ^ re-monitor the local processes by their identifiers
                        deriving (Eq, Show, Typeable, Generic)
 
 instance Binary TimeServerMessage
 
 -- | The message destined directly for the inbox process.
 data InboxProcessMessage = MonitorProcessMessage DP.ProcessId
                            -- ^ monitor the local process by its inbox process identifier
                          | ReMonitorProcessMessage [DP.ProcessId]
                            -- ^ re-monitor the local processes by their identifiers
                          | TrySendKeepAliveMessage
                            -- ^ try to send a keep alive message
                          | SendQueueMessage DP.ProcessId Message
@@ -165,16 +165,16 @@
                            -- ^ send the local time message to the time server
                          | SendRequestGlobalTimeMessage DP.ProcessId DP.ProcessId
                            -- ^ send the request for the global virtual time
-                         | SendRegisterLocalProcessMessage DP.ProcessId DP.ProcessId
-                           -- ^ register the local process in the time server
-                         | SendUnregisterLocalProcessMessage DP.ProcessId DP.ProcessId
-                           -- ^ unregister the local process from the time server
+                         | SendRegisterLogicalProcessMessage DP.ProcessId DP.ProcessId
+                           -- ^ register the logical process in the time server
+                         | SendUnregisterLogicalProcessMessage DP.ProcessId DP.ProcessId
+                           -- ^ unregister the logical process from the time server
                          | SendTerminateTimeServerMessage DP.ProcessId DP.ProcessId
-                           -- ^ the local process asked to terminate the time server
-                         | RegisterLocalProcessAcknowledgmentMessage DP.ProcessId
-                           -- ^ after registering the local process in the time server
-                         | UnregisterLocalProcessAcknowledgmentMessage DP.ProcessId
-                           -- ^ after unregistering the local process from the time server
+                           -- ^ the logical process asked to terminate the time server
+                         | RegisterLogicalProcessAcknowledgmentMessage DP.ProcessId
+                           -- ^ after registering the logical process in the time server
+                         | UnregisterLogicalProcessAcknowledgmentMessage DP.ProcessId
+                           -- ^ after unregistering the logical process from the time server
                          | TerminateTimeServerAcknowledgmentMessage DP.ProcessId
                            -- ^ after started terminating the time server
                          | TerminateInboxProcessMessage
@@ -106,51 +106,51 @@
                        | TerminateTimeServerMessage DP.ProcessId
-                         -- ^ the local process asked to terminate the time server
+                         -- ^ the logical process asked to terminate the time server
                        | RequestGlobalTimeMessage DP.ProcessId
@@ -106,51 +106,51 @@
                        | RequestGlobalTimeMessage DP.ProcessId
-                         -- ^ the local process requested for the global minimum time
+                         -- ^ the logical process requested for the global minimum time
                        | LocalTimeMessage DP.ProcessId Double
@@ -106,51 +106,51 @@
                        | LocalTimeMessage DP.ProcessId Double
-                         -- ^ the local process sent its local minimum time
+                         -- ^ the logical process sent its local minimum time
                        | ReMonitorTimeServerMessage [DP.ProcessId]
@@ -106,51 +106,51 @@
                        | ReMonitorTimeServerMessage [DP.ProcessId]
-                         -- ^ re-monitor the local processes by their identifiers
+                         -- ^ re-monitor the logical processes by their identifiers
                        deriving (Eq, Show, Typeable, Generic)
 
@@ -106,51 +106,51 @@
 -- | The message destined directly for the inbox process.
 data InboxProcessMessage = MonitorProcessMessage DP.ProcessId
-                           -- ^ monitor the local process by its inbox process identifier
+                           -- ^ monitor the logical process by its inbox process identifier
                          | ReMonitorProcessMessage [DP.ProcessId]
@@ -106,51 +106,51 @@
                          | ReMonitorProcessMessage [DP.ProcessId]
-                           -- ^ re-monitor the local processes by their identifiers
+                           -- ^ re-monitor the logical processes by their identifiers
                          | TrySendKeepAliveMessage
                            -- ^ try to send a keep alive message
diff --git a/Simulation/Aivika/Distributed/Optimistic/Internal/TimeServer.hs b/Simulation/Aivika/Distributed/Optimistic/Internal/TimeServer.hs
--- a/Simulation/Aivika/Distributed/Optimistic/Internal/TimeServer.hs
+++ b/Simulation/Aivika/Distributed/Optimistic/Internal/TimeServer.hs
@@ -64,13 +64,13 @@
   TimeServer { tsParams :: TimeServerParams,
                -- ^ the time server parameters
                tsInitQuorum :: Int,
                -- ^ the initial quorum of registered local processes to start the simulation
                tsInInit :: IORef Bool,
                -- ^ whether the time server is in the initial mode
                tsTerminating :: IORef Bool,
                -- ^ whether the time server is in the terminating mode
-               tsProcesses :: IORef (M.Map DP.ProcessId LocalProcessInfo),
-               -- ^ the information about local processes
+               tsProcesses :: IORef (M.Map DP.ProcessId LogicalProcessInfo),
+               -- ^ the information about logical processes
                tsProcessesInFind :: IORef (S.Set DP.ProcessId),
                -- ^ the processed used in the current finding of the global time
                tsGlobalTime :: IORef (Maybe Double),
@@ -79,13 +79,13 @@
                -- ^ the global time timestamp
              }
 
--- | The information about the local process.
-data LocalProcessInfo =
-  LocalProcessInfo { lpLocalTime :: IORef (Maybe Double),
-                     -- ^ the local time of the process
-                     lpMonitorRef :: Maybe DP.MonitorRef
-                     -- ^ the local process monitor reference
-                   }
+-- | The information about the logical process.
+data LogicalProcessInfo =
+  LogicalProcessInfo { lpLocalTime :: IORef (Maybe Double),
+                       -- ^ the local time of the process
+                       lpMonitorRef :: Maybe DP.MonitorRef
+                       -- ^ the logical process monitor reference
+                     }
 
 -- | The default time server parameters.
 defaultTimeServerParams :: TimeServerParams
@@ -121,7 +121,7 @@
 
 -- | Process the time server message.
 processTimeServerMessage :: TimeServer -> TimeServerMessage -> DP.Process ()
-processTimeServerMessage server (RegisterLocalProcessMessage pid) =
+processTimeServerMessage server (RegisterLogicalProcessMessage pid) =
   join $ liftIO $
   do m <- readIORef (tsProcesses server)
      case M.lookup pid m of
@@ -132,7 +132,7 @@
        Nothing  ->
          do t <- newIORef Nothing
             modifyIORef (tsProcesses server) $
-              M.insert pid LocalProcessInfo { lpLocalTime = t, lpMonitorRef = Nothing }
+              M.insert pid LogicalProcessInfo { lpLocalTime = t, lpMonitorRef = Nothing }
             return $
               do when (tsProcessMonitoringEnabled $ tsParams server) $
                    do logTimeServer server INFO $
@@ -142,9 +142,9 @@
                         modifyIORef (tsProcesses server) $
                         M.update (\x -> Just x { lpMonitorRef = Just r }) pid
                  serverId <- DP.getSelfPid
-                 DP.send pid (RegisterLocalProcessAcknowledgmentMessage serverId)
+                 DP.send pid (RegisterLogicalProcessAcknowledgmentMessage serverId)
                  tryStartTimeServer server
-processTimeServerMessage server (UnregisterLocalProcessMessage pid) =
+processTimeServerMessage server (UnregisterLogicalProcessMessage pid) =
   join $ liftIO $
   do m <- readIORef (tsProcesses server)
      case M.lookup pid m of
@@ -166,7 +166,7 @@
                             "Time Server: unmonitoring the process by identifier " ++ show pid
                           DP.unmonitor r
                  serverId <- DP.getSelfPid
-                 DP.send pid (UnregisterLocalProcessAcknowledgmentMessage serverId)
+                 DP.send pid (UnregisterLogicalProcessAcknowledgmentMessage serverId)
                  tryProvideTimeServerGlobalTime server
                  tryTerminateTimeServer server
 processTimeServerMessage server (TerminateTimeServerMessage pid) =
@@ -203,7 +203,7 @@
          return $
          do logTimeServer server WARNING $
               "Time Server: unknown process identifier " ++ show pid
-            processTimeServerMessage server (RegisterLocalProcessMessage pid)
+            processTimeServerMessage server (RegisterLogicalProcessMessage pid)
             processTimeServerMessage server (LocalTimeMessage pid t')
        Just x  ->
          do writeIORef (lpLocalTime x) (Just t')
@@ -250,7 +250,7 @@
                                 "Time Server: starting"
                               tryComputeTimeServerGlobalTime server
   
--- | Try to compute the global time and provide the local processes with it.
+-- | Try to compute the global time and provide the logical processes with it.
 tryComputeTimeServerGlobalTime :: TimeServer -> DP.Process ()
 tryComputeTimeServerGlobalTime server =
   join $ liftIO $
@@ -275,7 +275,7 @@
           writeIORef (tsProcessesInFind server) S.empty
           writeIORef (tsGlobalTimeTimestamp server) (Just utc)
 
--- | Try to provide the local processes wth the global time. 
+-- | Try to provide the logical processes wth the global time. 
 tryProvideTimeServerGlobalTime :: TimeServer -> DP.Process ()
 tryProvideTimeServerGlobalTime server =
   join $ liftIO $
@@ -303,7 +303,7 @@
      forM_ zs $ \(pid, x) ->
        DP.send pid ComputeLocalTimeMessage
 
--- | Provide the local processes with the global time.
+-- | Provide the logical processes with the global time.
 provideTimeServerGlobalTime :: TimeServer -> DP.Process ()
 provideTimeServerGlobalTime server =
   do t0 <- liftIO $ timeServerGlobalTime server
@@ -380,7 +380,7 @@
      C.throwM e
 
 -- | Start the time server by the specified initial quorum and parameters.
--- The quorum defines the number of local processes that must be registered in
+-- The quorum defines the number of logical processes that must be registered in
 -- the time server before the global time synchronization is started.
 timeServer :: Int -> TimeServerParams -> DP.Process ()
 timeServer n ps =
@@ -64,13 +64,13 @@
                -- ^ the time server parameters
                tsInitQuorum :: Int,
-               -- ^ the initial quorum of registered local processes to start the simulation
+               -- ^ the initial quorum of registered logical processes to start the simulation
                tsInInit :: IORef Bool,
                -- ^ whether the time server is in the initial mode